netapp_ontap.models.firmware_disk API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.firmware_disk`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class FirmwareDiskSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the FirmwareDisk object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `average_duration_per_disk: Size GET`

    Average firmware update duration per disk (in seconds).

    Example: 120

  `num_waiting_download: Size GET`

    The number of disks waiting to download the firmware update.

    Example: 0

  `total_completion_estimate: Size GET`

    Estimated firmware update duration to completion (in minutes).

    Example: 0

  `update_status: str GET`

    Status of the background disk firmware update.

    Valid choices:

    - running
    - idle